@@ -1,6 +1,6 @@
 use crate::{
     yubi,
-    zfs_mount::{zfs_create, zfs_mount},
+    zfs::{zfs_create, zfs_mount},
 };
 use sha2::{Digest, Sha512};
 use std::{io::Read, process::exit};
