@@ -1,10 +1,10 @@
 mod logic;
 mod yubi;
-mod zfs_mount;
+mod zfs;
 
 use crate::{
     logic::{create_zfs_file, create_zfs_yubi},
-    zfs_mount::{zfs_create, zfs_mount},
+    zfs::{zfs_create, zfs_mount},
 };
 use clap::{crate_authors, crate_version, App, Arg};
 use sha2::{Digest, Sha512};
